<?php

class JIVBoxTable
{
    private static $__instance = NULL;
//    private $__csv_file = '/disc/vboxtable-000-000.txt';
//    private $__csv_file = 'vboxtable-000-000.txt';
    private $__csv_file = '/disc/vboxtable.txt';
//    private $__csv_file = 'vboxtable.txt';
    private $__csvcontent_arr = array();
    private $__tableheader_arr = array();
    
    /*
     * Retrieve the object instance of the class
     * or create if nothing is set yet.
     * 
     * @return class instance
     */
    public static function GetInstance()
    {
        if(self::$__instance == NULL) {
            self::$__instance = new JIVBoxTable();
        }
        return self::$__instance;
    }
    
    /*
     * Checks if the designated CSV file exists.
     * 
     * @return boolean
     */
    public function CSVFileExists()
    {
        return file_exists($this->__csv_file);
    }
    
    /*
     * Retrieves the header menu defined in the table.
     * 
     * @return array
     */
    public function GetTableHeaderMenus()
    {
        return $this->__tableheader_arr;
    }
    
    /*
     * Retrieve the table header menu and put it into an array.
     */
    private function __GetTableHeader()
    {
        // Look for the line where the TABLE STARTS to determine
        // the position of the TABLE HEADER
        $needle = 'TABLE - START';
        $key = array_keys(array_filter($this->__csvcontent_arr, function($var) use ($needle) {
            return strpos($var, $needle) !== false;
        }))[0] + 1; // Add 1 to get the correct table header position
        // Save table header menu inside the array
        $this->__tableheader_arr = explode(',', trim($this->__csvcontent_arr[$key]));
    }
    
    /*
     * Retrieves the single record row in the table.
     * 
     * @param string Searched String
     * @param boolean Returns a string or array
     * 
     * @return string
     */
    private function __GetTableRecordRow($needle='', $single=TRUE)
    {
        // Get the first record row found inside the table
        $tbl_record_row = array_values(array_filter($this->__csvcontent_arr, function($var) use ($needle) {
            return strpos($var, $needle) !== false;
        }));
        return !empty($tbl_record_row) ? $single ? $tbl_record_row[0] : $tbl_record_row : '';
    }
    
    /*
     * Retrieves the value of a column in a table record.
     * 
     * @param string Table Record row
     * @param string Table Column name
     * 
     * @return string Column value
     */
    private function __GetTableRecordColumnValue($tbl_record_row='', $tbl_column_name='')
    {
        // Get the column position in the table header menu
        if(($column_index = array_search($tbl_column_name, $this->__tableheader_arr)) === FALSE) {
            return NULL; // If column name not found in the table header menu
        }
        // Split table record row by ","
        $tbl_record_row_arr = explode(',', $tbl_record_row);
        return trim($tbl_record_row_arr[$column_index]);
    }
    
    /*
     * Retrieves infomration about the firmware.
     * 
     * @return array
     */
    public function GetFirmwareInformation()
    {
        $firmware_info_arr = array();
        // Get the firmware row inside the table
        $firmware_row = $this->__GetTableRecordRow('FW');
        // Get firmware description
        $firmware_desc = $this->__GetTableRecordColumnValue($firmware_row, 'DESCRIPTION');
        // Split firmware description data by ","
        $firmware_desc_arr = explode(' ', $firmware_desc);
        // Save version
        $firmware_info_arr['version'] = trim($firmware_desc_arr[0]);
        // Save date
        $firmware_info_arr['date'] = trim(str_replace($firmware_desc_arr[0].' ', '', $firmware_desc));
        return $firmware_info_arr;
    }
    
    /*
     * Retrieves system's configuration settings.
     * 
     * @return array
     */
    public function GetSystemConfigurationSettings()
    {
        $sysconfig_arr = array();
        // Get the row contains the values inside the table
        $record_row = $this->__GetTableRecordRow('TIMP-001,', false);
        // Loop into each record line
        for($i = 0; $i < count($record_row); $i++) {
            $record = array();
            // Save MODEL
            $record['MODEL'] = $this->__GetTableRecordColumnValue($record_row[$i], 'MODEL');
            // Save SERIAL NO
            $record['SERIAL_NO'] = $this->__GetTableRecordColumnValue($record_row[$i], 'SERIAL No');
            // Save DID
            $record['DID'] = $this->__GetTableRecordColumnValue($record_row[$i], 'DID');
            // Save GLINK
            $record['GLINK'] = $this->__GetTableRecordColumnValue($record_row[$i], 'GLINK ORDER');
            // Save LABEL
            $record['LABEL'] = $this->__GetTableRecordColumnValue($record_row[$i], 'LABEL');
            $sysconfig_arr[] = $record;
        }
        return $sysconfig_arr;
    }
    
    /*
     * Initialize object requirements.
     */
    private function __construct()
    {
        // If CSV file exists begin parsing
        if($this->CSVFileExists()) {
            // Get the CSV content
            $this->__csvcontent_arr =  file($this->__csv_file);
//            print_r($this->__csvcontent_arr);
            // Initialize the table header menu
            $this->__GetTableHeader();
//            while(list($var, $val) = each($this->___csvcontent_arr)) {
//                ++$var;
//                $val = trim($val);
//                echo 'Line '.$var.': '.$val.'<br/>';
//            }
        }
    }
}